##  Example: Cloud migration with BTM
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274dc9357a4410149ef5f8118ca95621_LowRes.png)
To achieve this, the EA will work with respective Business Leaders to:
  1. Map affected Business Capabilities to the Objectives.
  2. Define plans to achieve Objective.
  3. Model impacts on affected Applications.
  4. Visualize plan based on multiple dimensions (e.g. time, cost, context).
  5. Decide, execute plan and track progress of Objective.


YesNo
Send
